# config-yaml

Serialize and deserialize your configurations/arguments to yaml. 

- A solution to experiment configuration recording.
- Compatible with `argparse`. Need least modifications to your original code using `argparse`.
- Small and extensible. Add anything you need on top of the module.

See `demo.ipynb` or [demo.html](https://vickyliin.github.io/config-yaml/demo/demo.html) for more examples and more details.
